@@ -525,7 +525,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
 
             #[endpoint {
                 method = PATCH,
-                path = "/payment/{correlation_id}/callback",
+                path = "/payment_callback/{correlation_id}",
             }]
             pub async fn callback_payment_endpoint(
                 req_ctx: Arc<RequestContext<ServerContext>>,
